@@ -9,13 +9,25 @@ from PyQt6.QtWidgets import (
     QLabel,
     QCheckBox,
     QVBoxLayout,
-    QSpacerItem,
-    QSizePolicy,
     QFrame,
 )
 
 from function2widgets.widget import BaseParameterWidget, WidgetArgs
 
+POS_TOP = 0
+POS_BOTTOM = 1
+
+LABEL_STYLESHEET = """QLabel{
+    font-family:Arial;
+    font-weight:600;
+}"""
+
+DESCRIPTION_STYLESHEET = """QLabel{
+    font-family:Arial;
+    font-weight: 300;
+    color: #424242;
+}"""
+
 
 @dataclasses.dataclass(frozen=True)
 class CommonParameterWidgetArgs(WidgetArgs):
@@ -25,9 +37,13 @@ class CommonParameterWidgetArgs(WidgetArgs):
     description: Optional[str] = None
     stylesheet: Optional[str] = None
     set_default_on_init: Optional[bool] = None
-    hide_default_widget: Optional[bool] = None
-    default_widget_text: Optional[str] = None
+    hide_default_value_widget: Optional[bool] = None
+    default_value_description: Optional[str] = None
     separate_line: bool = True
+    label_stylesheet: Optional[str] = None
+    description_position: Optional[int] = None
+    description_text_indent: Optional[int] = None
+    description_stylesheet: Optional[str] = None
 
 
 class CommonParameterWidget(BaseParameterWidget):
@@ -38,11 +54,40 @@ class CommonParameterWidget(BaseParameterWidget):
     OBJ_ID_CENTER_WIDGET = "_CPW_center_widget"
     OBJ_ID_LABEL_WIDGET = "_CPW_label_widget"
     OBJ_ID_DESCRIPTION_WIDGET = "_CPW_description_widget"
-    OBJ_ID_DEFAULT_WIDGET = "_CPW_default_widget"
+    OBJ_ID_DEFAULT_VALUE_WIDGET = "_CPW_default_widget"
     OBJ_ID_SEPARATE_LINE = "_CPW_separate_line_widget"
 
+    DEFAULT_LABEL_STYLESHEET = LABEL_STYLESHEET
+    DEFAULT_DESCRIPTION_POS = POS_TOP
+    DEFAULT_DESCRIPTION_TEXT_INDENT = -1
+    DEFAULT_DESCRIPTION_STYLESHEET = DESCRIPTION_STYLESHEET
+
     def __init__(self, args: CommonParameterWidgetArgs, parent: Optional[QWidget]):
 
+        description_pos = args.description_position
+        if description_pos is None:
+            description_pos = self.DEFAULT_DESCRIPTION_POS
+
+        description_text_indent = args.description_text_indent
+        if description_text_indent is None:
+            description_text_indent = self.DEFAULT_DESCRIPTION_TEXT_INDENT
+
+        label_stylesheet = args.label_stylesheet
+        if label_stylesheet is None:
+            label_stylesheet = self.DEFAULT_LABEL_STYLESHEET
+
+        description_stylesheet = args.description_stylesheet
+        if description_stylesheet is None:
+            description_stylesheet = self.DEFAULT_DESCRIPTION_STYLESHEET
+
+        args = dataclasses.replace(
+            args,
+            description_position=description_pos,
+            description_text_indent=description_text_indent,
+            label_stylesheet=label_stylesheet,
+            description_stylesheet=description_stylesheet,
+        )
+
         super().__init__(args=args, parent=parent)
 
         self._layout = QVBoxLayout(self)
@@ -109,14 +154,14 @@ class CommonParameterWidget(BaseParameterWidget):
         return self._description_widget.text()
 
     def _setup_default_widget(self):
-        if self._args.default_widget_text is None:
+        if self._args.default_value_description is None:
             text = "{}"
         else:
-            text = self._args.default_widget_text
+            text = self._args.default_value_description
         self._default_widget.setText(text.format(self._args.default))
         # noinspection PyUnresolvedReferences
         self._default_widget.toggled.connect(self._on_default_widget_state_changed)
-        self._default_widget.setHidden(self._args.hide_default_widget)
+        self._default_widget.setHidden(self._args.hide_default_value_widget is True)
 
     def _setup_label_widget(self):
         self._label_widget.setWordWrap(True)
@@ -125,6 +170,8 @@ class CommonParameterWidget(BaseParameterWidget):
             | Qt.AlignmentFlag.AlignLeft
             | Qt.AlignmentFlag.AlignTop
         )
+        self._label_widget.setWordWrap(False)
+        self._label_widget.setStyleSheet(self._args.label_stylesheet)
 
     def _setup_description_widget(self):
         self._description_widget.setWordWrap(True)
@@ -133,9 +180,13 @@ class CommonParameterWidget(BaseParameterWidget):
             | Qt.AlignmentFlag.AlignLeft
             | Qt.AlignmentFlag.AlignTop
         )
+        indent = self._args.description_text_indent or -1
+        self._description_widget.setIndent(indent)
+        self._description_widget.setWordWrap(True)
+        self._description_widget.setStyleSheet(self._args.description_stylesheet)
 
     def _on_default_widget_state_changed(self, checked: bool):
-        if self._args.hide_default_widget:
+        if self._args.hide_default_value_widget:
             return
         self._center_widget.setEnabled(not checked)
 
@@ -147,13 +198,25 @@ class CommonParameterWidget(BaseParameterWidget):
         self._label_widget.setObjectName(cls.OBJ_ID_LABEL_WIDGET)
         self._description_widget.setObjectName(cls.OBJ_ID_DESCRIPTION_WIDGET)
         self._center_widget.setObjectName(cls.OBJ_ID_CENTER_WIDGET)
-        self._default_widget.setObjectName(cls.OBJ_ID_DEFAULT_WIDGET)
+        self._default_widget.setObjectName(cls.OBJ_ID_DEFAULT_VALUE_WIDGET)
 
         self._layout.setContentsMargins(0, 0, 0, 0)
+
+        description_pos = (
+            self._args.description_position or self.DEFAULT_DESCRIPTION_POS
+        )
+
         self._layout.addWidget(self._label_widget)
+
+        if description_pos == POS_TOP:
+            self._layout.addWidget(self._description_widget)
+
         self._layout.addWidget(self._center_widget)
         self._layout.addWidget(self._default_widget)
-        self._layout.addWidget(self._description_widget)
+
+        if description_pos != POS_TOP:
+            self._layout.addWidget(self._description_widget)
+
         if self._args.separate_line:
             line = self._create_separate_line()
             self._layout.addWidget(line)
@@ -163,17 +226,17 @@ class CommonParameterWidget(BaseParameterWidget):
         # self._layout.addSpacerItem(spacer)
 
     def _is_use_default(self) -> bool:
-        if self._args.hide_default_widget or self._default_widget.isHidden():
+        if self._args.hide_default_value_widget or self._default_widget.isHidden():
             return False
         return self._default_widget.isChecked()
 
     def _use_default(self):
-        if self._args.hide_default_widget or self._default_widget.isHidden():
+        if self._args.hide_default_value_widget or self._default_widget.isHidden():
             return
         self._default_widget.setChecked(True)
 
     def _unuse_default(self):
-        if self._args.hide_default_widget or self._default_widget.isHidden():
+        if self._args.hide_default_value_widget or self._default_widget.isHidden():
             return
         self._default_widget.setChecked(False)
 
